# canvas_pyr

A Python canvas library powered by Skia, with bindings implemented in Rust.

## 来源与致谢

本项目的核心源自 [Brooooooklyn/canvas](https://github.com/Brooooooklyn/canvas)，该项目通过 [Node-API](https://napi.rs/) 为 Node.js 提供绑定。

本项目在此基础上，使用 [PyO3](https://pyo3.rs/) 使其能够作为 Python 扩展模块使用。

## 许可证

原项目遵循 MIT 许可证。本项目完整保留了其原始版权声明（见 `LICENSE` 文件），并在此基础上新增的 Python 绑定代码同样采用 MIT 许可证发布。

